@@ -19,6 +19,7 @@ from agiflow.opentelemetry.context import (
   set_association_properties,
   set_workflow_name,
   set_prompt_settings_context,
+  extract_association_properties_from_http_headers,
 )
 
 __all__ = [
@@ -40,4 +41,5 @@ __all__ = [
   'set_association_properties',
   'set_workflow_name',
   'set_prompt_settings_context',
+  'extract_association_properties_from_http_headers'
 ]
