@@ -21,6 +21,7 @@ from agiflow.opentelemetry.context.context_propagation import (
   get_trace_context_from_carrier,
   get_carrier_from_trace_context,
   extract_association_properties_from_http_headers,
+  apply_context_to_trace_span,
 )
 
 __all__ = [
@@ -39,5 +40,6 @@ __all__ = [
   'set_prompt_attributes_from_context',
   'get_trace_context_from_carrier',
   'get_carrier_from_trace_context',
-  'extract_association_properties_from_http_headers'
+  'extract_association_properties_from_http_headers',
+  'apply_context_to_trace_span'
 ]
