@@ -20,10 +20,10 @@ def set_prompt_attributes_from_context(span, context: Optional[Context] = None):
             if key == 'key':
                 span.set_attribute(SpanAttributes.AGIFLOW_PROMPT_KEY, value)
             if key == 'version':
-                span.set_attribute(SpanAttributes.AGIFLOW_PROMPT_KEY, value)
+                span.set_attribute(SpanAttributes.AGIFLOW_PROMPT_VERSION, value)
             if key == 'version_name':
-                span.set_attribute(SpanAttributes.AGIFLOW_PROMPT_KEY, value)
+                span.set_attribute(SpanAttributes.AGIFLOW_PROMPT_VERSION_NAME, value)
             if key == 'version_hash':
-                span.set_attribute(SpanAttributes.AGIFLOW_PROMPT_KEY, value)
+                span.set_attribute(SpanAttributes.AGIFLOW_PROMPT_VERSION, value)
             if key == 'template_variables':
-                span.set_attribute(SpanAttributes.AGIFLOW_PROMPT_KEY, value)
+                span.set_attribute(SpanAttributes.AGIFLOW_PROMPT_TEMPLATE_VARIABLES, value)
