@@ -17,6 +17,11 @@ class DatabaseSpanAttributes():
     DB_COLLECTION_NAME = 'db.collection.name'
     DB_TOP_K = 'db.top_k'
     DB_EMBEDDING_MODEL = 'db.embedding_model'
+    DB_QUERY_FILTER = 'db.query.filter'
+    DB_QUERY_INCLUDE_VALUES = 'db.query.include_values'
+    DB_QUERY_INCLUDE_METADATA = 'db.query.include_metadata'
+    DB_USAGE_READ_UNITS = 'db.usage.read_units'
+    DB_USAGE_WRITE_UNITS = 'db.usage.write_units'
 
 
 class DatabaseSpanAttributesValidator(AgiflowSpanAttributesValidator):
@@ -30,3 +35,8 @@ class DatabaseSpanAttributesValidator(AgiflowSpanAttributesValidator):
     DB_COLLECTION_NAME: Optional[str] = Field(None, alias=DatabaseSpanAttributes.DB_COLLECTION_NAME)
     DB_TOP_K: Optional[float] = Field(None, alias=DatabaseSpanAttributes.DB_TOP_K)
     DB_EMBEDDING_MODEL: Optional[str] = Field(None, alias=DatabaseSpanAttributes.DB_EMBEDDING_MODEL)
+    DB_QUERY_FILTER: Optional[str] = Field(None, alias=DatabaseSpanAttributes.DB_QUERY_FILTER)
+    DB_QUERY_INCLUDE_VALUES: Optional[str] = Field(None, alias=DatabaseSpanAttributes.DB_QUERY_INCLUDE_VALUES)
+    DB_QUERY_INCLUDE_METADATA: Optional[str] = Field(None, alias=DatabaseSpanAttributes.DB_QUERY_INCLUDE_METADATA)
+    DB_USAGE_READ_UNITS: Optional[str] = Field(None, alias=DatabaseSpanAttributes.DB_USAGE_READ_UNITS)
+    DB_USAGE_WRITE_UNITS: Optional[str] = Field(None, alias=DatabaseSpanAttributes.DB_USAGE_WRITE_UNITS)
