@@ -15,7 +15,7 @@ limitations under the License.
 """
 
 import importlib.metadata
-from agiflow.opentelemetry.convention import SpanAttributes
+from agiflow.opentelemetry.convention import SpanAttributes, AgiflowServiceTypes
 from agiflow.opentelemetry.instrumentation.constants.common import (
     SERVICE_PROVIDERS,
 )
@@ -40,4 +40,5 @@ class AnthropicSpanCapture(BaseSpanCapture):
             SpanAttributes.URL_FULL: base_url,
             SpanAttributes.AGIFLOW_SERVICE_NAME: service_provider,
             SpanAttributes.AGIFLOW_SERVICE_VERSION: importlib.metadata.version("anthropic"),
+            SpanAttributes.AGIFLOW_SERVICE_TYPE: AgiflowServiceTypes.LLM,
         })
