@@ -14,8 +14,10 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
+import importlib.metadata
+
 from agiflow.opentelemetry.instrumentation.constants import SERVICE_PROVIDERS
-from agiflow.opentelemetry.convention import SpanAttributes
+from agiflow.opentelemetry.convention import SpanAttributes, AgiflowServiceTypes
 from agiflow.opentelemetry.instrumentation.utils import BaseSpanCapture
 
 
@@ -32,5 +34,6 @@ class LangchainSpanCapture(BaseSpanCapture):
         service_provider = SERVICE_PROVIDERS["LANGCHAIN"]
         self.set_pydantic_attributes({
             SpanAttributes.AGIFLOW_SERVICE_NAME: service_provider,
-            SpanAttributes.AGIFLOW_SERVICE_VERSION: self.version,
+            SpanAttributes.AGIFLOW_SERVICE_VERSION: importlib.metadata.version("langchain"),
+            SpanAttributes.AGIFLOW_SERVICE_TYPE: AgiflowServiceTypes.FRAMEWORK,
         })
