@@ -14,7 +14,6 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-import json
 from typing import Any, Dict
 
 from agiflow.opentelemetry.instrumentation.constants.openai import APIS
@@ -107,33 +106,31 @@ class ChatCompletionSpanCapture(OpenAILLMSpanCapture):
             self.set_span_attribute(
                 SpanAttributes.LLM_SYSTEM_FINGERPRINT, result.system_fingerprint
             )
+
         # Get the usage
-        if hasattr(result, "usage") and result.usage is not None:
+        if hasattr(result, "usage"):
             usage = result.usage
             if usage is not None:
                 usage_dict = {
-                    LLMTokenUsageKeys.PROMPT_TOKENS: result.usage.prompt_tokens,
+                    LLMTokenUsageKeys.PROMPT_TOKENS: usage.prompt_tokens,
                     LLMTokenUsageKeys.COMPLETION_TOKENS: usage.completion_tokens,
                     LLMTokenUsageKeys.TOTAL_TOKENS: usage.total_tokens,
                 }
-                self.set_span_attribute(SpanAttributes.LLM_TOKEN_COUNTS, json.dumps(usage_dict))
-        self.span.set_status(StatusCode.OK)
-        self.span.end()
-        return result
+                self.set_span_attribute(SpanAttributes.LLM_TOKEN_COUNTS, serialise_to_json(usage_dict))
 
     def get_prompt_tokens(self, result):
         # iterate over kwargs.get("messages", {}) and calculate the prompt tokens
         prompt_tokens = 0
         for message in (self.messages or {}):
             prompt_tokens += calculate_prompt_tokens(
-                json.dumps(message), self.model
+                serialise_to_json(message), self.model
             )
 
         # iterate over kwargs.get("functions") and calculate the prompt tokens
         if self.functions is not None:
             for function in self.functions:
                 prompt_tokens += calculate_prompt_tokens(
-                    json.dumps(function), self.model
+                    serialise_to_json(function), self.model
                 )
 
         return prompt_tokens
@@ -208,7 +205,7 @@ class ChatCompletionSpanCapture(OpenAILLMSpanCapture):
         self.span.add_event(Event.STREAM_END)
         self.span.set_attribute(
             SpanAttributes.LLM_TOKEN_COUNTS,
-            json.dumps(
+            serialise_to_json(
                 {
                     LLMTokenUsageKeys.PROMPT_TOKENS: prompt_tokens,
                     LLMTokenUsageKeys.COMPLETION_TOKENS: self.tokens[
@@ -222,7 +219,7 @@ class ChatCompletionSpanCapture(OpenAILLMSpanCapture):
         )
         self.span.set_attribute(
             SpanAttributes.LLM_RESPONSES,
-            json.dumps(
+            serialise_to_json(
                 [
                     {
                         LLMResponseKeys.ROLE: "assistant",
