@@ -3,6 +3,14 @@ from agiflow.opentelemetry.utils.llm import (
   estimate_tokens_using_tiktoken,
   calculate_prompt_tokens,
   calculate_price_from_usage,
-  set_span_attributes,
   should_send_prompts,
 )
+
+
+__all__ = [
+  'estimate_tokens',
+  'estimate_tokens_using_tiktoken',
+  'calculate_prompt_tokens',
+  'calculate_price_from_usage',
+  'should_send_prompts',
+]
